==> haskell-network-info-0.2.0.8-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-network-info.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-info
version: 0.2.0.8
id: network-info-0.2.0.8-86rzpOQvMAKDGx0U3gGJUk
key: network-info-0.2.0.8-86rzpOQvMAKDGx0U3gGJUk
license: BSD3
maintainer: Jacob Stanley <jacob@stanley.io>
homepage: http://github.com/jystic/network-info
synopsis: Access the local computer'\''s basic network configuration
description:
    This library provides simple read-only access to the
    local computer'\''s networking configuration. It is
    currently capable of getting a list of all the network
    interfaces and their respective IPv4, IPv6 and MAC
    addresses.
    .
    network-info has been tested and is known to work on
    Ubuntu 10.10, FreeBSD 9.0, Mac OS X 10.6.4 and Windows
    XP/7. It probably works on other flavours of Linux,
    OS X, FreeBSD and Windows as well.
category: Network
author: Jacob Stanley
exposed: True
exposed-modules:
    Network.Info
abi: 3a77755072490bfe6d7add247381c2ff
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/network-info-0.2.0.8
library-dirs: /usr/lib/ghc-8.0.1/site-local/network-info-0.2.0.8
data-dir: /usr/share/arm-linux-ghc-8.0.1/network-info-0.2.0.8
hs-libraries: HSnetwork-info-0.2.0.8-86rzpOQvMAKDGx0U3gGJUk
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-network-info/html/network-info.haddock
haddock-html: /usr/share/doc/haskell-network-info/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-info-0.2.0.8-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-network-info.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-info
version: 0.2.0.8
id: network-info-0.2.0.8-3CNHbSDxkB04OXdr5Q0x5c
key: network-info-0.2.0.8-3CNHbSDxkB04OXdr5Q0x5c
license: BSD3
maintainer: Jacob Stanley <jacob@stanley.io>
homepage: http://github.com/jystic/network-info
synopsis: Access the local computer'\''s basic network configuration
description:
    This library provides simple read-only access to the
    local computer'\''s networking configuration. It is
    currently capable of getting a list of all the network
    interfaces and their respective IPv4, IPv6 and MAC
    addresses.
    .
    network-info has been tested and is known to work on
    Ubuntu 10.10, FreeBSD 9.0, Mac OS X 10.6.4 and Windows
    XP/7. It probably works on other flavours of Linux,
    OS X, FreeBSD and Windows as well.
category: Network
author: Jacob Stanley
exposed: True
exposed-modules:
    Network.Info
abi: fe498c8803634f246922fca7c58f4595
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/network-info-0.2.0.8
library-dirs: /usr/lib/ghc-8.0.2/site-local/network-info-0.2.0.8
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/network-info-0.2.0.8
hs-libraries: HSnetwork-info-0.2.0.8-3CNHbSDxkB04OXdr5Q0x5c
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-network-info/html/network-info.haddock
haddock-html: /usr/share/doc/haskell-network-info/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
